@@ -37,7 +37,7 @@ class PriorityClass(Resource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if self.value:
                 self.res["value"] = self.value
             if self.global_default:
